/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.krunner1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "krunner1adaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class Krunner1Adaptor
 */

Krunner1Adaptor::Krunner1Adaptor(AbstractKRunnerPlugin *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

Krunner1Adaptor::~Krunner1Adaptor()
{
    // destructor
}

RemoteActions Krunner1Adaptor::Actions()
{
    // handle method call org.kde.krunner1.Actions
    return parent()->Actions();
}

RemoteMatches Krunner1Adaptor::Match(const QString &query)
{
    // handle method call org.kde.krunner1.Match
    return parent()->Match(query);
}

void Krunner1Adaptor::Run(const QString &matchId, const QString &actionId)
{
    // handle method call org.kde.krunner1.Run
    parent()->Run(matchId, actionId);
}

void Krunner1Adaptor::Teardown()
{
    // handle method call org.kde.krunner1.Teardown
    parent()->Teardown();
}


#include "moc_krunner1adaptor.cpp"
