/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.krunner1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef KRUNNER1ADAPTOR_H
#define KRUNNER1ADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "abstractkrunnerplugin.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.krunner1
 */
class Krunner1Adaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.krunner1")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.krunner1\">\n"
"    <method name=\"Teardown\"/>\n"
"    <method name=\"Actions\">\n"
"      <annotation value=\"RemoteActions\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"out\" type=\"a(sss)\" name=\"matches\"/>\n"
"    </method>\n"
"    <method name=\"Run\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"matchId\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"actionId\"/>\n"
"    </method>\n"
"    <method name=\"Match\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"query\"/>\n"
"      <annotation value=\"RemoteMatches\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"out\" type=\"a(sssuda{sv})\" name=\"matches\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    Krunner1Adaptor(AbstractKRunnerPlugin *parent);
    ~Krunner1Adaptor() override;

    inline AbstractKRunnerPlugin *parent() const
    { return static_cast<AbstractKRunnerPlugin *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    RemoteActions Actions();
    RemoteMatches Match(const QString &query);
    void Run(const QString &matchId, const QString &actionId);
    void Teardown();
Q_SIGNALS: // SIGNALS
};

#endif
