// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "debug.h"


Q_LOGGING_CATEGORY(INTEGRATOR, "org.kde.plasma.browser-integration.flatpak.integrator", QtInfoMsg)

