/****************************************************************************
** Meta object code from reading C++ file 'mprisplugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-browser-integration-6.6.5/host/mprisplugin.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mprisplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11MPrisPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto MPrisPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN11MPrisPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MPrisPlugin",
        "fullscreenChanged",
        "",
        "canSetFullscreenChanged",
        "canControlChanged",
        "playbackStatusChanged",
        "canSeekChanged",
        "playbackRateChanged",
        "minimumRateChanged",
        "maximumRateChanged",
        "metadataChanged",
        "Identity",
        "DesktopEntry",
        "CanRaise",
        "Fullscreen",
        "CanSetFullscreen",
        "CanGoNext",
        "CanGoPrevious",
        "CanControl",
        "CanPause",
        "CanPlay",
        "CanSeek",
        "Volume",
        "Position",
        "Rate",
        "MinimumRate",
        "MaximumRate",
        "PlaybackStatus",
        "LoopStatus",
        "Metadata",
        "QVariantMap"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fullscreenChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSetFullscreenChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canControlChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playbackStatusChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSeekChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playbackRateChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimumRateChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximumRateChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'metadataChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Identity'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'DesktopEntry'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'CanRaise'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Fullscreen'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'CanSetFullscreen'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'CanGoNext'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'CanGoPrevious'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'CanControl'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'CanPause'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'CanPlay'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'CanSeek'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'Volume'
        QtMocHelpers::PropertyData<qreal>(22, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'Position'
        QtMocHelpers::PropertyData<qlonglong>(23, QMetaType::LongLong, QMC::DefaultPropertyFlags),
        // property 'Rate'
        QtMocHelpers::PropertyData<double>(24, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable, 5),
        // property 'MinimumRate'
        QtMocHelpers::PropertyData<double>(25, QMetaType::Double, QMC::DefaultPropertyFlags, 6),
        // property 'MaximumRate'
        QtMocHelpers::PropertyData<double>(26, QMetaType::Double, QMC::DefaultPropertyFlags, 7),
        // property 'PlaybackStatus'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'LoopStatus'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'Metadata'
        QtMocHelpers::PropertyData<QVariantMap>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MPrisPlugin, qt_meta_tag_ZN11MPrisPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MPrisPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractBrowserPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MPrisPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MPrisPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11MPrisPluginE_t>.metaTypes,
    nullptr
} };

void MPrisPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MPrisPlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fullscreenChanged(); break;
        case 1: _t->canSetFullscreenChanged(); break;
        case 2: _t->canControlChanged(); break;
        case 3: _t->playbackStatusChanged(); break;
        case 4: _t->canSeekChanged(); break;
        case 5: _t->playbackRateChanged(); break;
        case 6: _t->minimumRateChanged(); break;
        case 7: _t->maximumRateChanged(); break;
        case 8: _t->metadataChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MPrisPlugin::*)()>(_a, &MPrisPlugin::fullscreenChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MPrisPlugin::*)()>(_a, &MPrisPlugin::canSetFullscreenChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MPrisPlugin::*)()>(_a, &MPrisPlugin::canControlChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MPrisPlugin::*)()>(_a, &MPrisPlugin::playbackStatusChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MPrisPlugin::*)()>(_a, &MPrisPlugin::canSeekChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MPrisPlugin::*)()>(_a, &MPrisPlugin::playbackRateChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MPrisPlugin::*)()>(_a, &MPrisPlugin::minimumRateChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MPrisPlugin::*)()>(_a, &MPrisPlugin::maximumRateChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MPrisPlugin::*)()>(_a, &MPrisPlugin::metadataChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->identity(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->desktopEntry(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->canRaise(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->fullscreen(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->canSetFullscreen(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->canGoNext(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->canGoPrevious(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->canControl(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->canPause(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->canPlay(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->canSeek(); break;
        case 11: *reinterpret_cast<qreal*>(_v) = _t->volume(); break;
        case 12: *reinterpret_cast<qlonglong*>(_v) = _t->position(); break;
        case 13: *reinterpret_cast<double*>(_v) = _t->playbackRate(); break;
        case 14: *reinterpret_cast<double*>(_v) = _t->minimumRate(); break;
        case 15: *reinterpret_cast<double*>(_v) = _t->maximumRate(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->playbackStatus(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->loopStatus(); break;
        case 18: *reinterpret_cast<QVariantMap*>(_v) = _t->metadata(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setFullscreen(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setVolume(*reinterpret_cast<qreal*>(_v)); break;
        case 13: _t->setPlaybackRate(*reinterpret_cast<double*>(_v)); break;
        case 17: _t->setLoopStatus(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MPrisPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MPrisPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MPrisPluginE_t>.strings))
        return static_cast<void*>(this);
    return AbstractBrowserPlugin::qt_metacast(_clname);
}

int MPrisPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractBrowserPlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void MPrisPlugin::fullscreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MPrisPlugin::canSetFullscreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MPrisPlugin::canControlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MPrisPlugin::playbackStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MPrisPlugin::canSeekChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MPrisPlugin::playbackRateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void MPrisPlugin::minimumRateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void MPrisPlugin::maximumRateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void MPrisPlugin::metadataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
